# RL-Worlds    [![Upload Python Package](https://github.com/shuvoxcd01/RL-Worlds/actions/workflows/python-publish.yml/badge.svg)](https://github.com/shuvoxcd01/RL-Worlds/actions/workflows/python-publish.yml)

**RL-Worlds** is a collection of reinforcement learning (RL) environments designed to help researchers, students, and enthusiasts study and implement RL algorithms. All environments in this repository are built to adhere to the [Gymnasium](https://gymnasium.farama.org/) environment format, making them compatible with a wide range of RL libraries and tools.

---

## Available Environments

1. 🐾 Random Walk

2. 🌟 Thousand States Random Walk

3. 🌍 Grid World

4. 🌬️ Windy Grid World

5. Tunnel World
